# Kotlyn
**WARNING: CURRENTLY WINDOWS ONLY!**<br>
The best toolkit to build, run and compile Kotlin appications.


## Installation Guide
It's really easy, don't worry! 😘

1. Make sure python 🐍 is installed
```bash
python --version
```

2. Use pip to install the CLI
```bash
python -m pip install --upgrade kotlyn
```

3. Run the setup
```
python -m kotlyn !setup
```

4. Check if the installation is correct ✅
```bash
kotlyn !version
```